@@ -11,6 +11,21 @@ from dovado_rtl.simple_types import Metric
 from dovado_rtl.enums import RegressionModel
 
 
+def validate_power_of_2(value: List[str], ctx: typer.Context):
+    if len(ctx.params["parameters"]) != len(value):
+        raise BadParameter(
+            "power of 2 constraint must be specified for each parameter, mismatching list lengths"
+            + ", parameter list lenght:"
+            + str(len(ctx.params["parameters"]))
+            + ", constraint list length: "
+            + str(len(value))
+        )
+    for i in value:
+        if i not in {"y", "n"}:
+            raise BadParameter("Accepted input are only y/n")
+    return value
+
+
 def validate_int_metrics(value: List[int]):
     for i in value:
         if i < 0:
@@ -70,8 +85,9 @@ def ask_utilization_metrics(
             else:
                 parsed_list = pre_selected_metrics
                 pre_selected_metrics = None
-            if parsed_list and max([i for i in parsed_list if i > 0]) < len(
-                counter_dict
+            if parsed_list and (
+                parsed_list == []
+                or max([i for i in parsed_list if i > 0]) < len(counter_dict)
             ):
                 out: List[Metric] = [
                     counter_dict[i] for i in {i for i in parsed_list if i > 0}
